@@ -22,7 +22,7 @@ swatch <- function (x, bg = "white", ...)
     devRatio <- devSize[2] / devSize[1]
     
     plot(NA, NA, xlim=c(-0.1,1.1), ylim=0.5+c(-1,1)*devRatio*0.6, xlab="", ylab="", xaxt="n", yaxt="n", bty="n", asp=1)
-    rect(centres-width/2, 0.5-width/2, centres+width/2, 0.5+width/2, col=shades, border=NA)
+    rect(centres-width/2, 0.5-width/2, centres+width/2, 0.5+width/2, col=shades, border="grey50", lwd=2)
     
     par(oldPars)
 }
